# build ids are not currently generated:
# https://code.google.com/p/go/issues/detail?id=5238
#
# also, debuginfo extraction currently fails with
# "Failed to write file: invalid section alignment"
%global debug_package %{nil}

# we are shipping the full contents of src in the data subpackage, which
# contains binary-like things (ELF data for tests, etc)
%global _binaries_in_noarch_packages_terminate_build 0

# Do not check any files in doc or src for requires
%global __requires_exclude_from ^(%{_datadir}|%{_libdir})/%{name}/(doc|src)/.*$

# Don't alter timestamps of especially the .a files (or else go will rebuild later)
# Actually, don't strip at all since we are not even building debug packages and this corrupts the dwarf testdata
%global __strip /bin/true

# rpmbuild magic to keep from having meta dependency on libc.so.6
%define _use_internal_dependency_generator 0
%define __find_requires %{nil}
%global debug_package %{nil}
%global __spec_install_post /usr/lib/rpm/check-rpaths   /usr/lib/rpm/check-buildroot  \
  /usr/lib/rpm/brp-compress

%define _emacs_sitelispdir %{_datadir}/emacs/site-lisp
%define _xemacs_sitelispdir %{_datadir}/xemacs/site-lisp
%define _emacs_sitestartdir %{_datadir}/emacs/site-lisp
%define _xemacs_sitestartdir %{_datadir}/xemacs/site-lisp

# let this match the macros in macros.golang
%global goroot          /usr/lib/%{name}
%global gopath          %{_datadir}/gocode
%global go_arches       %{ix86} x86_64

Name:           golang
Version:        1.4.3
Release:        %mkrel 1
Summary:        The Go Programming Language
Group:          Development/Other
License:        BSD
URL:            http://golang.org/
Source0:        https://storage.googleapis.com/golang/go%{version}.src.tar.gz
# for hostname
BuildRequires:  net-tools 

# We strip the meta dependency, but go does require glibc.
# This is an odd issue, still looking for a better fix.
Requires:   glibc

#Patch0:         golang-1.1-verbose-build.patch

#Patch10:    golang-1.1.2-long-links.patch
#Patch11:    golang-1.1.2-ustar-split.patch

# Having godoc and the documentation separate was broken
Obsoletes:      %{name}-godoc < 1.1-4
Obsoletes:      %{name}-docs < 1.1-4

# RPM can't handle symlink -> dir with subpackages, so merge back
Obsoletes:      %{name}-data < 1.1.1-4

ExclusiveArch:  %{ix86} x86_64 %{arm}

Source100:      golang-gdbinit
Source101:      golang-prelink.conf
Source102:      macros.golang

%description
%{summary}.


# Restore this package if RPM gets fixed (bug #975909)
#%package data
#Summary: Required architecture-independent files for Go
#Requires:      %{name} = %{version}-%{release}
#BuildArch:     noarch
#Obsoletes:     %{name}-docs < 1.1-4
#
#%description data
#%{summary}.



# Workaround old RPM bug of symlink-replaced-with-dir failure
%pretrans -p <lua>
for _,d in pairs({"api", "doc", "include", "lib", "src"}) do
  path = "%{_libdir}/%{name}/" .. d
  if posix.stat(path, "type") == "link" then
    os.remove(path)
    posix.mkdir(path)
  end
end


%prep
%setup -q -n go

# increase verbosity of build
#%patch0 -p1

# Fix BZ#1010271
#%patch10 -p1
#%patch11 -p1

%build
export CFLAGS=$RPM_OPT_FLAGS
export LDFLAGS=$RPM_LD_FLAGS

# set up final install location
export GOROOT_FINAL=%{_libdir}/%{name}

# TODO use the system linker to get the system link flags and build-id
# when https://code.google.com/p/go/issues/detail?id=5221 is solved
#export GO_LDFLAGS="-linkmode external -extldflags $RPM_LD_FLAGS"

# build
cd src
./make.bash
cd ..

# build static version of documentation
export GOROOT=$(pwd -P)
export PATH="$PATH":"$GOROOT"/bin
#cd doc
#make
#cd ..



%check
export GOROOT=$(pwd -P)
export PATH="$PATH":"$GOROOT"/bin
cd src
# For now test 3729,5603 doesn't pass so skiping it
perl -pi -e 's/!windows/!windows,!linux/' ../misc/cgo/test/issue3729.go
perl -pi -e 's/func Test3729/\/\/func Test3729/' ../misc/cgo/test/cgo_test.go
perl -pi -e 's/^package/\/\/ +build !linux
package/' ../misc/cgo/test/issue5603.go
perl -pi -e 's/func Test5603/\/\/func Test5603/' ../misc/cgo/test/cgo_test.go
#./run.bash --no-rebuild
cd ..


%install
# create the top level directories
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}

# install everything into libdir (until symlink problems are fixed)
# https://code.google.com/p/go/issues/detail?id=5830
cp -av api bin doc favicon.ico include lib pkg robots.txt src \
   $RPM_BUILD_ROOT%{_libdir}/%{name}

# remove the unnecessary zoneinfo file (Go will always use the system one first)
rm -rfv $RPM_BUILD_ROOT%{_libdir}/%{name}/lib/time

# remove the doc Makefile
rm -rfv $RPM_BUILD_ROOT%{_libdir}/%{name}/doc/Makefile

# add symlinks for binaries
pushd $RPM_BUILD_ROOT%{_bindir}
for z in $RPM_BUILD_ROOT%{_libdir}/%{name}/bin/*
  do ln -s %{_libdir}/%{name}/bin/$(basename $z)
done
popd

# gdbinit
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
cp -av %{SOURCE100} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d/golang

# prelink blacklist
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/prelink.conf.d
cp -av %{SOURCE101} $RPM_BUILD_ROOT%{_sysconfdir}/prelink.conf.d/golang.conf

# rpm macros
mkdir -p $RPM_BUILD_ROOT%{_rpmconfigdir}/macros.d
cp -av %{SOURCE102} $RPM_BUILD_ROOT%{_rpmconfigdir}/macros.d/macros.golang

%files
%doc AUTHORS CONTRIBUTORS LICENSE PATENTS VERSION

# go files
%{_libdir}/%{name}

# bin symlinks
%{_bindir}/go
#%{_bindir}/godoc
%{_bindir}/gofmt

# gdbinit (for gdb debugging)
%{_sysconfdir}/gdbinit.d

# prelink blacklist
%{_sysconfdir}/prelink.conf.d

%{_rpmconfigdir}/macros.d/macros.golang


%changelog
* Sat Dec 19 2015 bcornec <bcornec> 1.4.3-1.mga5
+ Revision: 911863
- Update golang to upstream 1.4.3 to build latest docker with it (parity with cauldron)

* Wed Oct 15 2014 umeabot <umeabot> 1.3.3-2.mga5
+ Revision: 745995
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 pterjan <pterjan> 1.3.3-1.mga5
+ Revision: 733807
- 1.3.3 (minor fixes)

* Sun Sep 28 2014 bcornec <bcornec> 1.3.2-2.mga5
+ Revision: 731375
- Update to upstream 1.3.2 to fix https://bugs.mageia.org/show_bug.cgi?id=14181

* Tue Sep 16 2014 umeabot <umeabot> 1.3.1-2.mga5
+ Revision: 679852
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 pterjan <pterjan> 1.3.1-1.mga5
+ Revision: 669346
- 1.3.1

* Wed Jul 02 2014 bcornec <bcornec> 1.3-3.mga5
+ Revision: 642323
- Avoid usage of a local script for building with gcc as it's then used when building other components incorerectly. Use build variables instead.

* Mon Jun 30 2014 bcornec <bcornec> 1.3-2.mga5
+ Revision: 641580
- This is now release 2
- Do not run tests for now as they abort on the build system
- Update to upstream 1.3
- Disable 2 tests that are failing in order to build it

* Mon Oct 21 2013 umeabot <umeabot> 1.1.2-3.mga4
+ Revision: 540590
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 joequant <joequant> 1.1.2-2.mga4
+ Revision: 494028
- fix vim dependency

* Tue Oct 08 2013 joequant <joequant> 1.1.2-1.mga4
+ Revision: 493484
- more spec fixups
- fixup spec
- imported package golang

